@@ -2,11 +2,11 @@ use 5.010;
 use strict;
 use warnings;
 package Benchmark::Perl::Formance::Analyzer;
-BEGIN {
-  $Benchmark::Perl::Formance::Analyzer::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.006-9-gc1f28da
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Benchmark::Perl::Formance - analyze results
-$Benchmark::Perl::Formance::Analyzer::VERSION = '0.006';
+$Benchmark::Perl::Formance::Analyzer::VERSION = '0.007';
 1;
 
 __END__
@@ -25,7 +25,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
